@@ -1,3 +1,8 @@
+r"""
+This package contains the measures.
+Measures can either be losses or metrics depending on whether they're differentiable.
+"""
+
 from vp_suite.measure.image_wise import MSE, L1, SmoothL1, LPIPS, SSIM, PSNR
 from vp_suite.measure.fvd.fvd import FrechetVideoDistance
 
@@ -11,7 +16,7 @@ LOSS_CLASSES = {
     "ssim": SSIM,
     "psnr": PSNR,
     "fvd": FrechetVideoDistance
-}
+}  #: TODO
 AVAILABLE_LOSSES = LOSS_CLASSES.keys()
 
 # === metrics ==================================================================
@@ -24,5 +29,5 @@ METRIC_CLASSES = {
     "ssim": SSIM,
     "psnr": PSNR,
     "fvd": FrechetVideoDistance
-}
+}  #: TODO
 AVAILABLE_METRICS = METRIC_CLASSES.keys()
