@@ -12,6 +12,9 @@ class LSTM(VideoPredictionModel):
 
     # model-specific constants
     NAME = "NonConvLSTM"
+    PAPER_REFERENCE = None  #: The paper where this model was introduced first.
+    CODE_REFERENCE = None  #: The code location of the reference implementation.
+    MATCHES_REFERENCE: str = "No"  #: A comment indicating whether the implementation in this package matches the reference.
     CAN_HANDLE_ACTIONS = True
 
     # model hyperparameters
@@ -20,14 +23,14 @@ class LSTM(VideoPredictionModel):
     lstm_kernel_size = (5, 5)  #: TODO
     lstm_num_layers = 3  #: TODO
 
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(LSTM, self).__init__(device, **model_args)
+        super(LSTM, self).__init__(device, **model_kwargs)
 
         self.act_fn = nn.ReLU(inplace=True)
         self.pool = nn.MaxPool2d(2, 2)
@@ -62,14 +65,6 @@ class LSTM(VideoPredictionModel):
             self.dec3, TF.Resize((self.img_h, self.img_w))
         )
 
-    def _config(self):
-        return {
-            "bottleneck_dim": self.bottleneck_dim,
-            "lstm_hidden_dim": self.lstm_hidden_dim,
-            "lstm_kernel_size": self.lstm_kernel_size,
-            "lstm_num_layers": self.lstm_num_layers
-        }
-
     def encode(self, x):
         r"""
 
@@ -102,14 +97,14 @@ class LSTM(VideoPredictionModel):
         Returns:
 
         """
-        return self(x, pred_length=1, **kwargs)[0].squeeze(dim=1)
+        return self(x, pred_frames=1, **kwargs)[0].squeeze(dim=1)
 
-    def forward(self, x, pred_length=1, **kwargs):
+    def forward(self, x, pred_frames=1, **kwargs):
         r"""
 
         Args:
             x ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -148,7 +143,7 @@ class LSTM(VideoPredictionModel):
         preds = [self.decode(output)]
 
         # preds 2, 3, ...
-        for t in range(pred_length - 1):
+        for t in range(pred_frames - 1):
             encoded = self.encode(preds[-1])
             if self.action_conditional:
                 inflated_action = self.action_inflate(actions[t - T_in].flatten(1, -1))
