@@ -6,7 +6,7 @@ from tqdm import tqdm
 
 from vp_suite.measure.image_wise import MSE
 from vp_suite.base.base_model import VideoPredictionModel
-from vp_suite.models.model_blocks.phydnet import EncoderRNN, K2M
+from vp_suite.model_blocks.phydnet import EncoderRNN, K2M
 
 
 class PhyDNet(VideoPredictionModel):
@@ -16,6 +16,9 @@ class PhyDNet(VideoPredictionModel):
 
     # model-specific constants
     NAME = "PhyDNet"
+    PAPER_REFERENCE = "https://arxiv.org/abs/2003.01460"  #: The paper where this model was introduced first.
+    CODE_REFERENCE = "https://github.com/vincent-leguen/PhyDNet"  #: The code location of the reference implementation.
+    MATCHES_REFERENCE: str = "No"  #: A comment indicating whether the implementation in this package matches the reference.
     CAN_HANDLE_ACTIONS = True
 
     # model hyperparameters
@@ -23,14 +26,14 @@ class PhyDNet(VideoPredictionModel):
     phy_kernel_size = (7, 7)  #: TODO
     phy_cell_channels = 49  #: TODO
 
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(PhyDNet, self).__init__(device, **model_args)
+        super(PhyDNet, self).__init__(device, **model_kwargs)
 
         self.criterion = MSE(self.device)
         self.encoder = EncoderRNN(self.img_shape, self.phy_cell_channels, self.phy_kernel_size,
@@ -42,13 +45,6 @@ class PhyDNet(VideoPredictionModel):
                 self.constraints[ind, i, j] = 1
                 ind += 1
 
-    def _config(self):
-        return {
-            "moment_loss_scale": self.moment_loss_scale,
-            "phy_kernel_size": self.phy_kernel_size,
-            "phy_cell_channels": self.phy_cell_channels
-        }
-
     def pred_1(self, x, **kwargs):
         r"""
 
@@ -59,9 +55,9 @@ class PhyDNet(VideoPredictionModel):
         Returns:
 
         """
-        return self(x, pred_length=1, **kwargs)[0].squeeze(dim=1)
+        return self(x, pred_frames=1, **kwargs)[0].squeeze(dim=1)
 
-    def forward(self, frames, pred_length=1, **kwargs):
+    def forward(self, frames, pred_frames=1, **kwargs):
         r"""
 
         Note:
@@ -69,7 +65,7 @@ class PhyDNet(VideoPredictionModel):
 
         Args:
             frames ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -81,7 +77,7 @@ class PhyDNet(VideoPredictionModel):
         in_length = frames.shape[1]
         out_frames = []
 
-        empty_actions = torch.zeros(frames.shape[0], in_length + pred_length, device=self.device)
+        empty_actions = torch.zeros(frames.shape[0], in_length + pred_frames, device=self.device)
         actions = kwargs.get("actions", empty_actions)
         if self.action_conditional:
             if actions.equal(empty_actions) or actions.shape[-1] != self.action_size:
@@ -94,7 +90,7 @@ class PhyDNet(VideoPredictionModel):
 
         decoder_input = frames[:, -1, :, :, :]  # first decoder input = last image of input sequence
 
-        for di in range(pred_length):
+        for di in range(pred_frames):
             decoder_output, decoder_hidden, output_image, _, _ = self.encoder(decoder_input, actions[:, ac_index], (ac_index == 0))
             out_frames.append(output_image)
             decoder_input = output_image
