@@ -9,22 +9,22 @@ class SimpleV1(VideoPredictionModel):
     """
 
     # model-specific constants
-    NAME = "SimpleV1"
+    NAME = "Simple V1"
     REQUIRED_ARGS = ["img_shape", "action_size", "tensor_value_range", "temporal_dim"]
 
     # model hyperparameters
     temporal_dim = None  #: TODO
 
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(SimpleV1, self).__init__(device, **model_args)
+        super(SimpleV1, self).__init__(device, **model_kwargs)
 
-        self.min_context_frames = self.temporal_dim
+        self.MIN_CONTEXT_FRAMES = self.temporal_dim
         self.act_fn = nn.ReLU(inplace=True)
         self.cnn = nn.Conv3d(self.img_c, self.img_c, kernel_size=(self.temporal_dim, 5, 5),
                              stride=(1, 1, 1), padding=(0, 2, 2), bias=False)
@@ -41,14 +41,6 @@ class SimpleV1(VideoPredictionModel):
             clf_weights[i, i, -1, 2, 2] = 1.0
         self.cnn.weight.data = clf_weights
 
-    def _config(self):
-        r"""
-
-        Returns:
-
-        """
-        return {"temporal_dim": self.temporal_dim}
-
     def pred_1(self, x, **kwargs):
         r"""
 
@@ -63,12 +55,12 @@ class SimpleV1(VideoPredictionModel):
             raise ValueError("invalid number of frames given")
         return self.cnn(x).squeeze(dim=2)  # [b, c, h, w]
 
-    def forward(self, x, pred_length=1, **kwargs):
+    def forward(self, x, pred_frames=1, **kwargs):
         r"""
 
         Args:
             x ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -76,7 +68,7 @@ class SimpleV1(VideoPredictionModel):
         """
         x = x.transpose(1, 2)  # shape: [b, c, t, h, w]
         output_frames = []
-        for t in range(pred_length):
+        for t in range(pred_frames):
             input = x[:, :, -self.temporal_dim:]
             output_frames.append(self.pred_1(input))
         return torch.stack(output_frames, dim=1), None
@@ -88,29 +80,23 @@ class SimpleV2(VideoPredictionModel):
     """
 
     # model-specific constants
-    NAME = "SimpleV2"
+    NAME = "Simple V2"
     REQUIRED_ARGS = ["img_shape", "action_size", "tensor_value_range", "temporal_dim"]
 
     # model hyperparameters
     hidden_channels = 64  #: TODO
     temporal_dim = None  #: TODO
 
-    def _config(self):
-        return {
-            "temporal_dim": self.temporal_dim,
-            "hidden_channels": self.hidden_channels
-        }
-
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(SimpleV2, self).__init__(device, **model_args)
+        super(SimpleV2, self).__init__(device, **model_kwargs)
 
-        self.min_context_frames = self.temporal_dim
+        self.MIN_CONTEXT_FRAMES = self.temporal_dim
         self.act_fn = nn.ReLU(inplace=True)
         self.big_branch = nn.Sequential(
             nn.Conv3d(self.img_c, self.hidden_channels, (self.temporal_dim, 5, 5), (1, 1, 1), (0, 2, 2), bias=False),
@@ -150,12 +136,12 @@ class SimpleV2(VideoPredictionModel):
         out = self.final_merge(torch.cat([big_branch, last_frame], dim=1))
         return out
 
-    def forward(self, x, pred_length=1, **kwargs):
+    def forward(self, x, pred_frames=1, **kwargs):
         r"""
 
         Args:
             x ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -163,7 +149,7 @@ class SimpleV2(VideoPredictionModel):
         """
         x = x.transpose(1, 2)  # shape: [b, c, t, h, w]
         output_frames = []
-        for t in range(pred_length):
+        for t in range(pred_frames):
             input = x[:, :, -self.temporal_dim:]
             output_frames.append(self.pred_1(input))
         return torch.stack(output_frames, dim=1), None
