@@ -9,9 +9,9 @@ import torch.nn.functional as F
 
 from vp_suite.measure.image_wise import MSE
 from vp_suite.base.base_model import VideoPredictionModel
-from vp_suite.models.model_blocks.enc import Autoencoder
-from vp_suite.models.model_blocks.st_lstm import STLSTMCell, ActionConditionalSTLSTMCell
-from vp_suite.models.model_blocks.phydnet import PhyCell_Cell, K2M
+from vp_suite.model_blocks import Autoencoder
+from vp_suite.model_blocks.predrnn import SpatioTemporalLSTMCell, ActionConditionalSpatioTemporalLSTMCell
+from vp_suite.model_blocks.phydnet import PhyCell_Cell, K2M
 
 
 class STPhy(VideoPredictionModel):
@@ -33,24 +33,24 @@ class STPhy(VideoPredictionModel):
     decoupling_loss_scale = 100.0  #: TODO
     moment_loss_scale = 1.0  #: TODO
 
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(STPhy, self).__init__(device, **model_args)
+        super(STPhy, self).__init__(device, **model_kwargs)
 
         self.dim_st_hidden = [self.st_cell_channels] * self.num_layers
         self.dim_phy_hidden = [self.phy_cell_channels] * self.num_layers
 
         self.autoencoder = Autoencoder(self.img_shape, self.st_cell_channels, self.device)
         _, _, self.enc_h, self.enc_w = self.autoencoder.encoded_shape
-        self.recurrent_cell = STLSTMCell
+        self.recurrent_cell = SpatioTemporalLSTMCell
 
         if self.action_conditional:
-            self.recurrent_cell = ActionConditionalSTLSTMCell
+            self.recurrent_cell = ActionConditionalSpatioTemporalLSTMCell
             self.action_inflate = nn.Linear(in_features=self.action_size,
                                             out_features=self.inflated_action_dim * self.enc_h * self.enc_w,
                                             bias=False)
@@ -86,18 +86,6 @@ class STPhy(VideoPredictionModel):
                 ind += 1
         self.criterion = MSE(device=self.device)
 
-    def _config(self):
-        return {
-            "phy_kernel_size": self.phy_kernel_size,
-            "phy_cell_channels": self.phy_cell_channels,
-            "st_cell_channels": self.st_cell_channels,
-            "num_layers": self.num_layers,
-            "inflated_action_dim": self.inflated_action_dim,
-            "reconstruction_loss_scale": self.reconstruction_loss_scale,
-            "decoupling_loss_scale": self.decoupling_loss_scale,
-            "moment_loss_scale": self.moment_loss_scale
-        }
-
     def pred_1(self, x, **kwargs):
         r"""
 
@@ -108,14 +96,14 @@ class STPhy(VideoPredictionModel):
         Returns:
 
         """
-        return self(x, pred_length=1, **kwargs)[0].squeeze(dim=1)
+        return self(x, pred_frames=1, **kwargs)[0].squeeze(dim=1)
 
-    def forward(self, input, pred_length=1, **kwargs):
+    def forward(self, input, pred_frames=1, **kwargs):
         r"""
 
         Args:
             input ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -124,7 +112,7 @@ class STPhy(VideoPredictionModel):
 
         frames = input.transpose(0, 1)  # [t, b, c, h, w]
         input_length, batch_size, _, _, _ = frames.shape
-        T = input_length + pred_length
+        T = input_length + pred_frames
         out_frames = []
 
         empty_actions = torch.zeros(batch_size, T, device=self.device)
@@ -199,7 +187,7 @@ class STPhy(VideoPredictionModel):
             decouple_loss.append(torch.mean(torch.abs(decouple_loss_)))
 
         out_frames = torch.stack(out_frames, dim=1)
-        reconstructions, predictions = out_frames.split([input_length-1, pred_length], dim=1)
+        reconstructions, predictions = out_frames.split([input_length - 1, pred_frames], dim=1)
 
         losses = {
             "reconstruction": self.criterion(reconstructions, input[:, 1:]),
@@ -235,7 +223,7 @@ class STPhy(VideoPredictionModel):
             actions = data["actions"].to(self.device)
 
             predictions, model_losses \
-                = self(input_frames, pred_length=config["pred_frames"], actions=actions,
+                = self(input_frames, pred_frames=config["pred_frames"], actions=actions,
                                teacher_forcing_ratio=teacher_forcing_ratio, target_frames=target_frames)
 
             # loss
