@@ -2,7 +2,7 @@ import torch
 from torch import nn as nn
 from torchvision.transforms import functional as TF
 
-from vp_suite.models.model_blocks.conv import DoubleConv3d, DoubleConv2d
+from vp_suite.model_blocks import DoubleConv3d, DoubleConv2d
 from vp_suite.base.base_model import VideoPredictionModel
 
 
@@ -20,16 +20,16 @@ class UNet3D(VideoPredictionModel):
     features = [8, 16, 32, 64]  #: TODO
     temporal_dim = None  #: TODO
 
-    def __init__(self, device, **model_args):
+    def __init__(self, device, **model_kwargs):
         r"""
 
         Args:
             device ():
-            **model_args ():
+            **model_kwargs ():
         """
-        super(UNet3D, self).__init__(device, **model_args)
+        super(UNet3D, self).__init__(device, **model_kwargs)
 
-        self.min_context_frames = self.temporal_dim
+        self.MIN_CONTEXT_FRAMES = self.temporal_dim
         self.downs = nn.ModuleList()
         self.ups = nn.ModuleList()
         self.time3ds = nn.ModuleList()
@@ -72,12 +72,6 @@ class UNet3D(VideoPredictionModel):
         # final
         self.final_conv = nn.Conv2d(in_channels=self.features[0], out_channels=self.img_c, kernel_size=(1, 1))
 
-    def _config(self):
-        return {
-            "temporal_dim": self.temporal_dim,
-            "features": self.features
-        }
-
     def pred_1(self, x, **kwargs):
         r"""
         input: T frames: [b, T, c, h, w] and T actions: [b, T, a]
@@ -137,14 +131,14 @@ class UNet3D(VideoPredictionModel):
         # FINAL
         return self.final_conv(x)
 
-    def forward(self, x, pred_length=1, **kwargs):
+    def forward(self, x, pred_frames=1, **kwargs):
         r"""
         input: T_in frames: [b, T_in, c, h, w]
-        output: pred_length (P) frames: [b, P, c, h, w]
+        output: pred_frames (P) frames: [b, P, c, h, w]
 
         Args:
             x ():
-            pred_length ():
+            pred_frames ():
             **kwargs ():
 
         Returns:
@@ -154,10 +148,10 @@ class UNet3D(VideoPredictionModel):
 
         # actions
         b, input_length, _, _, _ = x.shape
-        empty_actions = torch.zeros(b, input_length + pred_length, device=self.device)
+        empty_actions = torch.zeros(b, input_length + pred_frames, device=self.device)
         actions = kwargs.get("actions", empty_actions)
 
-        for t in range(pred_length):
+        for t in range(pred_frames):
             pred = self.pred_1(x, actions=actions)
             pred = pred.unsqueeze(dim=1)
             preds.append(pred)
